//时间转换为：分:秒
export function secondFormate(seconds) {
	let minute, second;
	minute = Math.floor(seconds / 60);
	minute = minute > 9 ? minute : '0' + minute;
	second = Math.floor(seconds % 60);
	second = second > 9 ? second : '0' + second;
	return `${minute}:${second}`;
}

//时间转换为：时:分:秒
export function thirdFormate(seconds) {
	let minute, second, hour;
	hour = Math.floor(seconds / 3600);
	hour = hour > 9 ? hour : '0' + hour;
	minute = Math.floor(seconds % 3600 / 60);
	minute = minute > 9 ? minute : '0' + minute;
	second = Math.floor(seconds % 3600 % 60);
	second = second > 9 ? second : '0' + second;
	return `${hour}:${minute}:${second}`;
}

//时间戳转换为：年-月-日 时:分:秒
export function formatDateTime(value) {
	if (value == undefined) {
		return;
	}
	let date = new Date(value * 1000);
	// let date = new Date(value);
	//时间戳为10位需*1000，时间戳为13位的话不需乘1000
	let y = date.getFullYear();
	let MM = date.getMonth() + 1;
	MM = MM < 10 ? ('0' + MM) : MM; //月补0
	let d = date.getDate();
	d = d < 10 ? ('0' + d) : d; //天补0
	let h = date.getHours();
	h = h < 10 ? ('0' + h) : h; //小时补0
	let m = date.getMinutes();
	m = m < 10 ? ('0' + m) : m; //分钟补0
	let s = date.getSeconds();
	s = s < 10 ? ('0' + s) : s; //秒补0
	// return y + '-' + MM + '-' + d; //年月日
	return y + '-' + MM + '-' + d + ' ' + h + ':' + m + ':' + s; //年月日时分秒
}

//时间戳转换为：年-月-日
export function formatDate(value) {
	if (value == undefined) {
		return;
	}
	let date = new Date(value * 1000);
	// let date = new Date(value);
	//时间戳为10位需*1000，时间戳为13位的话不需乘1000
	let y = date.getFullYear();
	let MM = date.getMonth() + 1;
	MM = MM < 10 ? ('0' + MM) : MM; //月补0
	let d = date.getDate();
	d = d < 10 ? ('0' + d) : d; //天补0
	return y + '-' + MM + '-' + d
}

//时间戳转换为：时:分:秒
export function formatTime(value) {
	if (value == undefined) {
		return;
	}
	let date = new Date(value * 1000);
	// let date = new Date(value);
	//时间戳为10位需*1000，时间戳为13位的话不需乘1000
	let h = date.getHours();
	h = h < 10 ? ('0' + h) : h; //小时补0
	let m = date.getMinutes();
	m = m < 10 ? ('0' + m) : m; //分钟补0
	let s = date.getSeconds();
	s = s < 10 ? ('0' + s) : s; //秒补0
	return h + ':' + m + ':' + s; //年月日时分秒
}

export function range(num, min, max) {
	return Math.min(Math.max(num, min), max);
}

export function addNumber(num1, num2) {
	const cardinal = 10 ** 10;
	return Math.round((num1 + num2) * cardinal) / cardinal;
}

//文件大小
export function sizeFormate(size) {
	const per = 1024 * 1024;
	return size >= per ? Number(size / per).toFixed(2) + 'M' : Number(size / 1024).toFixed(2) + 'kb';
}

//url次数
export function getUrlQuery(url) {
	// 用JS拿到URL，如果函数接收了URL，那就用函数的参数。如果没传参，就使用当前页面的URL
	let queryString = url ? url.split('?')[1] : window.location.search.slice(1);
	// 用来存储我们所有的参数
	let obj = {};
	// 如果没有传参，返回一个空对象
	if (!queryString) {
		return obj;
	}
	// stuff after # is not part of query string, so get rid of it
	queryString = queryString.split('#')[0];
	// 将参数分成数组
	let arr = queryString.split('&');
	for (let i = 0; i < arr.length; i++) {
		// 分离成key:value的形式
		let a = arr[i].split('=');
		// 将undefined标记为true
		let paramName = a[0];
		let paramValue = typeof(a[1]) === 'undefined' ? true : a[1];
		// 如果调用对象时要求大小写区分，可删除这两行代码
		// paramName = paramName.toLowerCase();
		// if (typeof paramValue === 'string') paramValue = paramValue.toLowerCase();
		// 如果paramName以方括号结束, e.g. colors[] or colors[2]
		if (paramName.match(/\[(\d+)?\]$/)) {
			// 如果paramName不存在，则创建key
			let key = paramName.replace(/\[(\d+)?\]/, '');
			if (!obj[key]) obj[key] = [];
			// 如果是索引数组 e.g. colors[2]
			if (paramName.match(/\[\d+\]$/)) {
				// 获取索引值并在对应的位置添加值
				let index = /\[(\d+)\]/.exec(paramName)[1];
				obj[key][index] = paramValue;
			} else {
				// 如果是其它的类型，也放到数组中
				obj[key].push(paramValue);
			}
		} else {
			// 处理字符串类型
			if (!obj[paramName]) {
				// 如果如果paramName不存在，则创建对象的属性
				obj[paramName] = paramValue;
			} else if (obj[paramName] && typeof obj[paramName] === 'string') {
				// 如果属性存在，并且是个字符串，那么就转换为数组
				obj[paramName] = [obj[paramName]];
				obj[paramName].push(paramValue);
			} else {
				// 如果是其它的类型，还是往数组里丢
				obj[paramName].push(paramValue);
			}
		}
	}
	return obj;
}