import {
	buyAlbum
} from '@/static/api/album.js'
import {
	buyLive
} from '@/static/api/live.js'
import {
	buyGoods
} from '@/static/api/goods.js'
import {
	buyActivity
} from '@/static/api/activity.js'
import {
	buyPack
} from '@/static/api/pack.js'

const {
	platform
} = uni.getSystemInfoSync();

function callPay(data, cb, that) {
	switch (data.type) {
		case 'album':
			buyAlbum({
				album_id: data.id,
				pay_for: data.pay_for
			}).then(res => {
				if (res.code == 1) { //调用支付
					pay(res.data, data.pay_for, function(status) {
						cb(status)
					})
				} else {
					that.$refs.uToast.show({
						type: 'error',
						message: res.msg,
					});
				}
			})
			break;
		case 'live':
			buyLive({
				live_id: data.id,
				pay_for: data.pay_for
			}).then(res => {
				if (res.code == 1) { //调用支付
					pay(res.data, data.pay_for, function(status) {
						cb(status)
					})
				} else {
					that.$refs.uToast.show({
						type: 'error',
						message: res.msg,
					});
				}
			})
			break;
		case 'goods':
			buyGoods({
				goods_id: data.id,
				count: data.count,
				address_id: data.address_id,
				pay: data.pay_for,
				money: data.price
			}).then(res => {
				if (res.code == 1) { //调用支付
					pay(res.data, data.pay_for, function(status) {
						cb(status)
					})
				} else {
					that.$refs.uToast.show({
						type: 'error',
						message: res.msg,
					});
				}
			})
			break;
		case 'activity':
			buyActivity({
				activity_id: data.id,
				pay: data.pay_for,
			}).then(res => {
				// console.log(res)
				if (res.code == 1) { //调用支付
					pay(res.data, data.pay_for, function(status) {
						cb(status)
					})
				} else {
					that.$refs.uToast.show({
						type: 'error',
						message: res.msg,
					});
				}
			})
			break;
		case 'pack':
			buyPack({
				album_ids: data.id,
				pay: data.pay_for,
				cateId: data.cateId,
				packid: data.packid,
			}).then(res => {
				// console.log(res)
				if (res.code == 1) { //调用支付
					pay(res.data, data.pay_for, function(status) {
						cb(status)
					})
				} else {
					that.$refs.uToast.show({
						type: 'error',
						message: res.msg,
					});
				}
			})
			break;
		default:
			that.$refs.uToast.show({
				type: 'error',
				message: '开发中。。。',
			});
	}
}

function pay(data, pay_for, cb) {
	switch (pay_for) {
		case 'alipay':
			aliPay(data, cb);
			break;
		case 'wxpay':
			wxpay(data, cb);
			break;
		case 'lcnpay': //余额支付
			cb(true);
			break;
	}
}

//阿里支付
function aliPay(data, cb) {
	let orderInfo;
	switch (platform) {
		case 'android':
			orderInfo = data.alipay.basic
			break;
		case 'ios':
			orderInfo = data.alipay.ios
			break;
	}
	// console.log(orderInfo)

	uni.requestPayment({
		provider: 'alipay',
		orderInfo: orderInfo,
		success: function(res) {
			cb(true)
		},
		fail: function(err) {
			cb(false)
		}
	});
}

//微信支付
function wxpay(data, cb) {
	let orderInfo;
	switch (platform) {
		case 'ios':
			orderInfo = data.wxpay.ios
			break;
		default:
			orderInfo = data.wxpay.basic
	}
	console.log(orderInfo)

	uni.requestPayment({
		provider: 'wxpay',
		orderInfo: orderInfo,
		success: function(res) {
			console.log(res)
			cb(true)
		},
		fail: function(err) {
			console.log(err)
			cb(false)
		}
	});
}

module.exports = {
	callPay,
	pay
}